# gameofcard
On the continent of Westeros, King Robert Baratheon governs the Kingdom
of the Seven Crowns ...

No, no, no. It's just a humble implementation of different card games.

## Actualy 0.0.4

For now only a simple ___briscola___ game is implemented.

The next game implemented will be ___Hearts___

## Wanna Try ?
```
python3 -m gameofcard
```
